:root {
    --primary-color: #5DDD8B;
    --primary-dark: #51c279;
    --background-color: #f9f9f9;
    --text-color: #071437;
    --link-hover-color: #4db874;
    --bs-card-border-radius: 0.625rem;
}

body {
    background-color: var(--background-color) !important;
    color: var(--text-color) !important;
    font-family: Inter, Helvetica, "sans-serif";
}

a {
    color: var(--primary-color) !important;
    text-decoration: none; /* Optional: removes underline from links */
}

.bg-primary {
    background-color: var(--primary-color) !important;
}

a:hover {
    color: var(--link-hover-color) !important;
}

.text-primary {
    color: var(--primary-color) !important;
}

.btn-primary {
    background-color: var(--primary-color);
    color: white !important; /* Ensures text on buttons is readable */
    border: none; /* Assuming you want button borders removed */
}

.bg-success {
    background-color: var(--primary-color) !important;
}

.btn-primary:hover {
    color: #ffffff !important;
    background-color: var(--primary-dark) !important;
}

.dark header {
    background-color: #161b22 !important;
    border-bottom-color: #161b22 !important;
}

.card {
    background-color: #ffffff !important;
    border-radius: var(--bs-card-border-radius);
}

.bg-primary {
    background-color: var(--primary-color) !important;
}

.nav .nav-item .nav-link.active {
    background-color: var(--primary-color);
    color: white !important; /* Ensures text on buttons is readable */
}

.w-50px {
    width: 50px !important;
    min-width: 50px !important;
    max-width: 50px !important;
}

.fw-small {
    font-size: 10px !important;
}

.text-light-grey {
    color: #bec6cc !important;
}

.card-header {
    padding-top: 20px !important;
    padding-bottom: 20px !important;
    vertical-align: middle !important;
    background-color: #ffffff !important;
}

.card-header .card-title {
    padding: 0 !important;
    margin: 0 !important;
}

.table thead tr {
    border-bottom: 1px dashed silver !important;
}

.table>:not(caption)>*>* {
    border-bottom: 0 !important;
}

pre {
    font-size: 1rem;
}