{% load static %}
<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Django Sonar</title>
    <link rel="shortcut icon" href="{% static 'django_sonar/media/logos/favicon.png' %}">
    <link rel="stylesheet" href="{% static 'django_sonar/css/bootstrap.min.css' %}">
    <link rel="stylesheet" href="{% static 'django_sonar/css/django-sonar.css' %}">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">
</head>
<body class="">

    {% block content %}{% endblock %}

</body>
</html>